XX精灵
======

1 简介
------

.. code:: bash

    1. 使用pynput实现键盘鼠标的监听与控制
        1.1 监听键盘鼠标操作并录制为脚本文件
        1.2 执行录制的脚本文件回放键盘鼠标操作
    2. 图形化界面使用tkinter实现

2 安装与使用
------------

2.1 安装
^^^^^^^^

.. code:: bash

    pip3 install xx_wizard

2.2 使用
^^^^^^^^

.. code:: bash

    from xx_wizard import Wizard
    Wizard().run()


3 功能介绍
----------

3.1 录制
^^^^^^^^

3.1.0 界面预览


|image0|

3.1.1 脚本名称

.. code:: bash

    本次录制存储的脚本名称, 名称不存在则新建, 已存在则覆盖

3.1.2 鼠标轨迹


.. code:: bash

    是否记录鼠标轨迹, 默认开启

3.1.3 鼠标间隔


.. code:: bash

    开启鼠标轨迹后, 轨迹坐标间隔超过x像素时才会记录到脚本中, 数值越小轨迹越平滑, 相应的记录的脚本体积也越大

3.1.4 录制热键


.. code:: bash

    使用键盘控制开始录制和停止录制, 按下该键跟鼠标点击按钮起到相同的效果

3.1.5 窗口隐藏


.. code:: bash

    录制开始时最小化窗口, 录制结束后窗口恢复

3.2 回放
^^^^^^^^

3.2.0 界面预览


|image1|

3.2.1 脚本名称

.. code:: bash

    下拉选择一个要回放的脚本, 如果没有请先录制

3.2.2 重复次数


.. code:: bash

    重复执行脚本的次数, 默认为0, 即不重复执行

3.2.3 重复间隔


.. code:: bash

    重复次数大于0时, 执行完一次脚本延迟x秒后重复下一次执行

3.2.4 回放热键


.. code:: bash

    使用键盘控制开始回放和停止回放, 按下该键跟鼠标点击按钮起到相同的效果

3.2.5 窗口隐藏


.. code:: bash

    回放开始时最小化窗口, 回放结束后窗口恢复

.. |image0| image:: https://oscimg.oschina.net/oscnet/up-b476be130a1d1eea814476244b0e53e21f0.png
.. |image1| image:: https://oscimg.oschina.net/oscnet/up-1641384eedd99e9bc0ab52200e1006f9e21.png


更新记录
=========
**1.1.0**

    - 修改

        - 提示信息改为鼠标悬浮时展示
        - 修改切换界面时鼠标样式

**1.0.4**

    - 修改

        - 修改描述信息
        - 修改说明文档

**1.0.3**

    - 修改

        - 代码结构调整
        - 修改使用说明

**1.0.2**

    - 修改

        - 修改使用说明

**1.0.1**

    - 新增

        - 增加说明文档

**1.0**

    - 新增

        - 发布第一个版本
